# TZSMM Pay Django Library

A Django-compatible Python library to interact with the TZSMM Pay API.

## Features
- Create transactions
- Verify transactions

## Installation
```bash
pip install tzsmmpay-django
